==> jc-1.4.0.tar.gz: soot/jimple/parser/node/TIntegerConstant.h <==
// public final class soot.jimple.parser.node.TIntegerConstant

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b64c5cc79b9bb8d1 soot_jimple_parser_node_TIntegerConstant
// @dep_class 84249dd9d0b5395d soot_jimple_parser_node_Token

// header file dependencies
// @dep_header soot_jimple_parser_node_Token

#include "soot/jimple/parser/node/Token.h"

#ifndef _JC_soot_jimple_parser_node_TIntegerConstant_H_
#define _JC_soot_jimple_parser_node_TIntegerConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_TIntegerConstant$sub_refs	_jc_soot_jimple_parser_node_TIntegerConstant$sub_refs;
typedef struct _jc_soot_jimple_parser_node_TIntegerConstant$sub_nonrefs	_jc_soot_jimple_parser_node_TIntegerConstant$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_TIntegerConstant$refs	_jc_soot_jimple_parser_node_TIntegerConstant$refs;
typedef struct _jc_soot_jimple_parser_node_TIntegerConstant$nonrefs	_jc_soot_jimple_parser_node_TIntegerConstant$nonrefs;
typedef struct _jc_soot_jimple_parser_node_TIntegerConstant$object	_jc_soot_jimple_parser_node_TIntegerConstant$object;

typedef const struct _jc_soot_jimple_parser_node_TIntegerConstant$vmethods	_jc_soot_jimple_parser_node_TIntegerConstant$vmethods;
typedef const struct _jc_soot_jimple_parser_node_TIntegerConstant$vtable	_jc_soot_jimple_parser_node_TIntegerConstant$vtable;
typedef const struct _jc_soot_jimple_parser_node_TIntegerConstant$vtype	_jc_soot_jimple_parser_node_TIntegerConstant$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_TIntegerConstant$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_parser_node_TIntegerConstant$object *, struct _jc_java_lang_String$object *);
extern void _jc_soot_jimple_parser_node_TIntegerConstant$method$_init$c8ef0122855cf0c5(_jc_env *, struct _jc_soot_jimple_parser_node_TIntegerConstant$object *, struct _jc_java_lang_String$object *, jint, jint);

// Virtual methods
extern void _jc_soot_jimple_parser_node_TIntegerConstant$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_TIntegerConstant$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_TIntegerConstant$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_TIntegerConstant$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_TIntegerConstant$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_TIntegerConstant$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_TIntegerConstant$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_TIntegerConstant$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_TIntegerConstant$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_TIntegerConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_Token$vmethods	soot_jimple_parser_node_Token;
	_jc_soot_jimple_parser_node_TIntegerConstant$vmethods	soot_jimple_parser_node_TIntegerConstant;
};

// Vtype
struct _jc_soot_jimple_parser_node_TIntegerConstant$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_TIntegerConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TIntegerConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_TIntegerConstant$refs {
    _jc_soot_jimple_parser_node_TIntegerConstant$sub_refs	soot_jimple_parser_node_TIntegerConstant;
    _jc_soot_jimple_parser_node_Token$sub_refs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TIntegerConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_TIntegerConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_Token$sub_nonrefs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_TIntegerConstant$sub_nonrefs	soot_jimple_parser_node_TIntegerConstant;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_TIntegerConstant$object {
	_jc_soot_jimple_parser_node_TIntegerConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_TIntegerConstant$vtype	*vtype;
	_jc_soot_jimple_parser_node_TIntegerConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_TIntegerConstant$vtype _jc_soot_jimple_parser_node_TIntegerConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_TIntegerConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_TIntegerConstant$class_object;

#endif	/* _JC_soot_jimple_parser_node_TIntegerConstant_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/TIntegerConstant.h <==
// public final class soot.jimple.parser.node.TIntegerConstant

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class b64c5cc79b9bb8d1 soot_jimple_parser_node_TIntegerConstant
// @dep_class 84249dd9d0b5395d soot_jimple_parser_node_Token

// header file dependencies
// @dep_header soot_jimple_parser_node_Token

#include "soot/jimple/parser/node/Token.h"

#ifndef _JC_soot_jimple_parser_node_TIntegerConstant_H_
#define _JC_soot_jimple_parser_node_TIntegerConstant_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_TIntegerConstant$sub_refs	_jc_soot_jimple_parser_node_TIntegerConstant$sub_refs;
typedef struct _jc_soot_jimple_parser_node_TIntegerConstant$sub_nonrefs	_jc_soot_jimple_parser_node_TIntegerConstant$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_TIntegerConstant$refs	_jc_soot_jimple_parser_node_TIntegerConstant$refs;
typedef struct _jc_soot_jimple_parser_node_TIntegerConstant$nonrefs	_jc_soot_jimple_parser_node_TIntegerConstant$nonrefs;
typedef struct _jc_soot_jimple_parser_node_TIntegerConstant$object	_jc_soot_jimple_parser_node_TIntegerConstant$object;

typedef const struct _jc_soot_jimple_parser_node_TIntegerConstant$vmethods	_jc_soot_jimple_parser_node_TIntegerConstant$vmethods;
typedef const struct _jc_soot_jimple_parser_node_TIntegerConstant$vtable	_jc_soot_jimple_parser_node_TIntegerConstant$vtable;
typedef const struct _jc_soot_jimple_parser_node_TIntegerConstant$vtype	_jc_soot_jimple_parser_node_TIntegerConstant$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_TIntegerConstant$method$_init$c31b894660454d13(_jc_env *, struct _jc_soot_jimple_parser_node_TIntegerConstant$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_TIntegerConstant$method$_init$c8ef0122855cf0c5(_jc_env *, struct _jc_soot_jimple_parser_node_TIntegerConstant$object *, struct _jc_java_lang_String$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_TIntegerConstant$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_TIntegerConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_TIntegerConstant$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_TIntegerConstant$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_TIntegerConstant$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_TIntegerConstant$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_TIntegerConstant$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_TIntegerConstant$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_TIntegerConstant$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_TIntegerConstant$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_Token$vmethods	soot_jimple_parser_node_Token;
	_jc_soot_jimple_parser_node_TIntegerConstant$vmethods	soot_jimple_parser_node_TIntegerConstant;
};

// Vtype
struct _jc_soot_jimple_parser_node_TIntegerConstant$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_TIntegerConstant$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TIntegerConstant$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_TIntegerConstant$refs {
    _jc_soot_jimple_parser_node_TIntegerConstant$sub_refs	soot_jimple_parser_node_TIntegerConstant;
    _jc_soot_jimple_parser_node_Token$sub_refs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_TIntegerConstant$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_TIntegerConstant$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_Token$sub_nonrefs	soot_jimple_parser_node_Token;
    _jc_soot_jimple_parser_node_TIntegerConstant$sub_nonrefs	soot_jimple_parser_node_TIntegerConstant;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_TIntegerConstant$object {
	_jc_soot_jimple_parser_node_TIntegerConstant$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_TIntegerConstant$vtype	*vtype;
	_jc_soot_jimple_parser_node_TIntegerConstant$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_TIntegerConstant$vtype _jc_soot_jimple_parser_node_TIntegerConstant$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_TIntegerConstant, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_TIntegerConstant$class_object;

#endif	/* _JC_soot_jimple_parser_node_TIntegerConstant_H_ */
